@@ -166,6 +166,8 @@ poppler_document_save (PopplerDocument  *document,
     GooString *fname = new GooString (filename);
 
     retval = document->doc->saveAs (fname);
+
+    delete fname;
   }
 
   return retval;
@@ -315,6 +317,43 @@ poppler_document_get_attachments (PopplerDocument *document)
   return g_list_reverse (retval);
 }
 
+/**
+ * poppler_document_find_dest:
+ * @document: A #PopplerDocument
+ * @link_name: a named destination
+ *
+ * Finds named destination @link_name in @document
+ *
+ * Return value: The #PopplerDest destination or %NULL if
+ * @link_name is not a destination. Returned value must
+ * be freed with #poppler_dest_free
+ **/
+PopplerDest *
+poppler_document_find_dest (PopplerDocument *document,
+			    const gchar     *link_name)
+{
+	PopplerDest *dest = NULL;
+	LinkDest *link_dest = NULL;
+	UGooString *g_link_name;
+
+	g_return_val_if_fail (POPPLER_IS_DOCUMENT (document), NULL);
+	g_return_val_if_fail (link_name != NULL, NULL);
+
+	g_link_name = new UGooString (link_name);
+
+	if (g_link_name) {
+		link_dest = document->doc->findDest (g_link_name);
+		delete g_link_name;
+	}
+
+	if (link_dest) {
+		dest = _poppler_dest_new_goto (document, link_dest);
+		delete link_dest;
+	}
+
+	return dest;
+}
+
 char *_poppler_goo_string_to_utf8(GooString *s)
 {
   char *result;
@@ -374,7 +413,7 @@ info_dict_get_date (Dict *info_dict, const gchar *key, GValue *value)
   int year, mon, day, hour, min, sec;
   int scanned_items;
   struct tm *time;
-  gchar *date_string;
+  gchar *date_string, *ds;
   GTime result;
 
   if (!info_dict->lookup ((gchar *)key, &obj)->isString ()) {
@@ -391,7 +430,8 @@ info_dict_get_date (Dict *info_dict, const gchar *key, GValue *value)
   } else {
     date_string = g_strndup (goo_value->getCString (), goo_value->getLength ());
   }
-
+  ds = date_string;
+  
   /* See PDF Reference 1.3, Section 3.8.2 for PDF Date representation */
 
   if (date_string [0] == 'D' && date_string [1] == ':')
@@ -401,9 +441,12 @@ info_dict_get_date (Dict *info_dict, const gchar *key, GValue *value)
   scanned_items = sscanf (date_string, "%4d%2d%2d%2d%2d%2d",
 		&year, &mon, &day, &hour, &min, &sec);
 
-  if (scanned_items != 6)
+  if (scanned_items != 6) {
+    obj.free ();
+    g_free (ds);
     return;
-
+  }
+  
   /* Workaround for y2k bug in Distiller 3, hoping that it won't
    * be used after y2.2k */
   if (year < 1930 && strlen (date_string) > 14) {
@@ -411,9 +454,12 @@ info_dict_get_date (Dict *info_dict, const gchar *key, GValue *value)
     scanned_items = sscanf (date_string, "%2d%3d%2d%2d%2d%2d%2d",
 		&century, &years_since_1900, &mon, &day, &hour, &min, &sec);
 						
-    if (scanned_items != 7)
+    if (scanned_items != 7) {
+      obj.free ();
+      g_free (ds);
       return;
-	
+    }
+    
     year = century * 100 + years_since_1900;
   }
 
@@ -431,12 +477,15 @@ info_dict_get_date (Dict *info_dict, const gchar *key, GValue *value)
  
   /* compute tm_wday and tm_yday and check date */
   if (mktime (time) == (time_t) - 1) {
+    obj.free ();
+    g_free (ds);
     return;
   } else {
   	result = mktime (time);
   }       
     
   obj.free ();
+  g_free (ds);
   
   g_value_set_int (value, result);
 }
@@ -503,6 +552,7 @@ poppler_document_get_property (GObject    *object,
       document->doc->getDocInfo (&obj);
       if (obj.isDict ())
 	info_dict_get_string (obj.getDict(), "Title", value);
+      obj.free ();
       break;
     case PROP_FORMAT:
       str = g_strndup("PDF-", 15); /* allocates 16 chars, pads with \0s */
@@ -514,36 +564,43 @@ poppler_document_get_property (GObject    *object,
       document->doc->getDocInfo (&obj);
       if (obj.isDict ())
 	info_dict_get_string (obj.getDict(), "Author", value);
+      obj.free ();
       break;
     case PROP_SUBJECT:
       document->doc->getDocInfo (&obj);
       if (obj.isDict ())
 	info_dict_get_string (obj.getDict(), "Subject", value);
+      obj.free ();
       break;
     case PROP_KEYWORDS:
       document->doc->getDocInfo (&obj);
       if (obj.isDict ())
 	info_dict_get_string (obj.getDict(), "Keywords", value);
+      obj.free ();
       break;
     case PROP_CREATOR:
       document->doc->getDocInfo (&obj);
       if (obj.isDict ())
 	info_dict_get_string (obj.getDict(), "Creator", value);
+      obj.free ();
       break;
     case PROP_PRODUCER:
       document->doc->getDocInfo (&obj);
       if (obj.isDict ())
 	info_dict_get_string (obj.getDict(), "Producer", value);
+      obj.free ();
       break;
     case PROP_CREATION_DATE:
       document->doc->getDocInfo (&obj);
       if (obj.isDict ())
 	info_dict_get_date (obj.getDict(), "CreationDate", value);
+      obj.free ();
       break;
     case PROP_MOD_DATE:
       document->doc->getDocInfo (&obj);
       if (obj.isDict ())
 	info_dict_get_date (obj.getDict(), "ModDate", value);
+      obj.free ();
 	break;
     case PROP_LINEARIZED:
       if (document->doc->isLinearized ()) {	
@@ -980,7 +1037,6 @@ poppler_index_iter_free (PopplerIndexIter *iter)
 		return;
 
 	g_object_unref (iter->document);
-//	delete iter->items;
 	g_free (iter);
 	
 }
@@ -1169,8 +1225,47 @@ poppler_font_info_free (PopplerFontInfo *font_info)
 	g_return_if_fail (font_info != NULL);
 
 	delete font_info->scanner;
-
 	g_object_unref (font_info->document);
+	g_free (font_info);
+}
+
+
+typedef struct _PopplerPSFileClass PopplerPSFileClass;
+struct _PopplerPSFileClass
+{
+        GObjectClass parent_class;
+};
+
+G_DEFINE_TYPE (PopplerPSFile, poppler_ps_file, G_TYPE_OBJECT);
+
+static void poppler_ps_file_finalize (GObject *object);
+
+
+static void
+poppler_ps_file_class_init (PopplerPSFileClass *klass)
+{
+        GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
+
+        gobject_class->finalize = poppler_ps_file_finalize;
+}
+
+static void
+poppler_ps_file_init (PopplerPSFile *ps_file)
+{
+        ps_file->out = NULL;
+        ps_file->paper_width = -1;
+        ps_file->paper_height = -1;
+        ps_file->duplex = FALSE;
+}
+
+static void
+poppler_ps_file_finalize (GObject *object)
+{
+        PopplerPSFile *ps_file = POPPLER_PS_FILE (object);
+
+        delete ps_file->out;
+        g_object_unref (ps_file->document);
+        g_free (ps_file->filename);
 }
 
 /**
@@ -1194,12 +1289,12 @@ poppler_ps_file_new (PopplerDocument *document, const char *filename,
 	g_return_val_if_fail (filename != NULL, NULL);
 	g_return_val_if_fail (n_pages > 0, NULL);
 
-	ps_file = g_new0 (PopplerPSFile, 1);
+        ps_file = (PopplerPSFile *) g_object_new (POPPLER_TYPE_PS_FILE, NULL);
 	ps_file->document = (PopplerDocument *) g_object_ref (document);
         ps_file->filename = g_strdup (filename);
         ps_file->first_page = first_page + 1;
         ps_file->last_page = first_page + 1 + n_pages - 1;
-        
+
 	return ps_file;
 }
 
@@ -1251,11 +1346,5 @@ void
 poppler_ps_file_free (PopplerPSFile *ps_file)
 {
 	g_return_if_fail (ps_file != NULL);
-
-	delete ps_file->out;
-	g_object_unref (ps_file->document);
-        g_free (ps_file->filename);
-	g_free (ps_file);
+        g_object_unref (ps_file);
 }
-
-
