@@ -2,28 +2,38 @@
 /* Generated data (by glib-mkenums) */
 
 #ifndef __POPPLER_TYPE_ENUMS_H__
-#define __POPPLER_TYPE_ENUMS_H__
+#define __POPPLER_TYPE_ENUMS_H__ 1
 
 #include <glib-object.h>
 
 G_BEGIN_DECLS
-/* enumerations from "poppler-action.h" */
-GType poppler_action_type_get_type (void) G_GNUC_CONST;
+
+
+/* --- poppler-action.h --- */
 #define POPPLER_TYPE_ACTION_TYPE (poppler_action_type_get_type())
-GType poppler_dest_type_get_type (void) G_GNUC_CONST;
+GType poppler_action_type_get_type (void) G_GNUC_CONST;
 #define POPPLER_TYPE_DEST_TYPE (poppler_dest_type_get_type())
-/* enumerations from "poppler-document.h" */
-GType poppler_page_layout_get_type (void) G_GNUC_CONST;
+GType poppler_dest_type_get_type (void) G_GNUC_CONST;
+
+/* --- poppler-document.h --- */
 #define POPPLER_TYPE_PAGE_LAYOUT (poppler_page_layout_get_type())
-GType poppler_page_mode_get_type (void) G_GNUC_CONST;
+GType poppler_page_layout_get_type (void) G_GNUC_CONST;
 #define POPPLER_TYPE_PAGE_MODE (poppler_page_mode_get_type())
-GType poppler_viewer_preferences_get_type (void) G_GNUC_CONST;
+GType poppler_page_mode_get_type (void) G_GNUC_CONST;
+#define POPPLER_TYPE_FONT_TYPE (poppler_font_type_get_type())
+GType poppler_font_type_get_type (void) G_GNUC_CONST;
 #define POPPLER_TYPE_VIEWER_PREFERENCES (poppler_viewer_preferences_get_type())
-/* enumerations from "poppler.h" */
-GType poppler_error_get_type (void) G_GNUC_CONST;
+GType poppler_viewer_preferences_get_type (void) G_GNUC_CONST;
+#define POPPLER_TYPE_PERMISSIONS (poppler_permissions_get_type())
+GType poppler_permissions_get_type (void) G_GNUC_CONST;
+
+/* --- poppler.h --- */
 #define POPPLER_TYPE_ERROR (poppler_error_get_type())
-GType poppler_orientation_get_type (void) G_GNUC_CONST;
+GType poppler_error_get_type (void) G_GNUC_CONST;
 #define POPPLER_TYPE_ORIENTATION (poppler_orientation_get_type())
+GType poppler_orientation_get_type (void) G_GNUC_CONST;
+#define POPPLER_TYPE_BACKEND (poppler_backend_get_type())
+GType poppler_backend_get_type (void) G_GNUC_CONST;
 G_END_DECLS
 
 #endif /* __POPPLER_TYPE_ENUMS_H__ */
