@@ -18,6 +18,7 @@
 #include "Catalog.h"
 #include "Gfx.h"
 #include "Lexer.h"
+#include "UGooString.h"
 #include "Annot.h"
 
 //------------------------------------------------------------------------
@@ -210,15 +211,14 @@ void Annot::generateAppearance(Dict *acroForm, Dict *dict) {
 
     // build the appearance stream dictionary
     appearDict.initDict(xref);
-    appearDict.dictAdd(copyString("Length"),
-		       obj1.initInt(appearBuf->getLength()));
-    appearDict.dictAdd(copyString("Subtype"), obj1.initName("Form"));
+    appearDict.dictAdd("Length", obj1.initInt(appearBuf->getLength()));
+    appearDict.dictAdd("Subtype", obj1.initName("Form"));
     obj1.initArray(xref);
     obj1.arrayAdd(obj2.initReal(0));
     obj1.arrayAdd(obj2.initReal(0));
     obj1.arrayAdd(obj2.initReal(xMax - xMin));
     obj1.arrayAdd(obj2.initReal(yMax - yMin));
-    appearDict.dictAdd(copyString("BBox"), &obj1);
+    appearDict.dictAdd("BBox", &obj1);
 
     // find the resource dictionary
     dict->lookup("DR", &drObj);
@@ -243,7 +243,7 @@ void Annot::generateAppearance(Dict *acroForm, Dict *dict) {
       }
     }
     if (drObj.isDict()) {
-      appearDict.dictAdd(copyString("Resources"), drObj.copy(&obj1));
+      appearDict.dictAdd("Resources", drObj.copy(&obj1));
     }
     drObj.free();
 
