@@ -390,7 +390,7 @@ void SampledFunction::transform(double *in, double *out) {
       for (k = 0, t = j; k < m; ++k, t >>= 1) {
 	idx += idxMul[k] * (e[k][t & 1]);
       }
-      s[j] = samples[idx];
+      if (idx >= 0 && idx < nSamples) s[j] = samples[idx];
     }
 
     // do m sets of interpolations
