@@ -66,7 +66,7 @@ namespace Poppler {
     class DocumentData {
     public:
 	DocumentData(GooString *filePath, GooString *ownerPassword, GooString *userPassword) :
-	    doc(filePath, ownerPassword, userPassword), m_splashOutputDev(0)
+	    doc(filePath, ownerPassword, userPassword), m_fontInfoScanner(0), m_splashOutputDev(0)
 	    {
 		paperColor = Qt::white;
 		// It might be more appropriate to delete these in PDFDoc
